# dayu_widgets_tag
![](docs/_media/logo.svg)

<a href="https://img.shields.io/pypi/pyversions/dayu_widgets_tag"><img src="https://img.shields.io/pypi/pyversions/dayu_widgets_tag" alt="python version"></a>
<a href="https://badge.fury.io/py/dayu_widgets_tag"><img src="https://img.shields.io/pypi/v/dayu_widgets_tag?color=green" alt="PyPI version"></a>
<img src="https://img.shields.io/pypi/dw/dayu_widgets_tag" alt="Downloads Status">
<img src="https://img.shields.io/pypi/l/dayu_widgets_tag" alt="License">
<img src="https://img.shields.io/pypi/format/dayu_widgets_tag" alt="pypi format">
<img src="https://img.shields.io/badge/Maintained%3F-yes-green.svg" alt="Maintenance">
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-1-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END --> 


Tag component is a dayu_widgets plugin

See the document:
* [中文](https://muyr.github.io/dayu_widgets_tag/#/zh-cn/)
* [EN](https://muyr.github.io/dayu_widgets_tag/)

## Install
```pip install dayu_widgets_tag```

## Basic
![](docs/_media/basic.png)

## Preset Color
![](docs/_media/preset-color.png)

## Custom Color
![](docs/_media/custom-color.png)

## Checkable
![](docs/_media/tag_checkable_light.gif)

## Add and Delete
![](docs/_media/tag_add_delete_light.gif)

